@@ -8,7 +8,7 @@ package Excel::Writer::XLSX::Chart::Column;
 #
 # See formatting note in Excel::Writer::XLSX::Chart.
 #
-# Copyright 2000-2015, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2017, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.86';
+our $VERSION = '0.96';
 
 
 ###############################################################################
@@ -117,9 +117,6 @@ sub _write_bar_chart {
     # Write the c:ser elements.
     $self->_write_ser( $_ ) for @series;
 
-    # Write the c:marker element.
-    $self->_write_marker_value();
-
     if ( $args{primary_axes} ) {
         # Write the c:gapWidth element.
         $self->_write_gap_width( $self->{_series_gap_1} );
@@ -309,7 +306,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright MM-MMXV, John McNamara.
+Copyright MM-MMXVII, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
